@@ -1,6 +1,6 @@
 from datetime import datetime
 from enum import Enum, IntEnum, unique
-from typing import Any, Dict, NamedTuple, Set
+from typing import Any, Dict, NamedTuple, Optional, Set
 from uuid import UUID
 
 from pydantic import BaseModel
@@ -32,16 +32,21 @@ class KhUser(NamedTuple) :
 	token: AuthToken
 	scope: Set[Scope]
 
-	def __hash__(self) :
+	def __hash__(self) -> int :
 		return hash(f'{self.user_id}{self.scope}')
 
 
+	def __str__(self) -> str :
+		# this is here for caching purposes
+		return str(self.user_id)
+
+
 class PublicKeyResponse(BaseModel) :
 	algorithm: str
 	key: str
 	signature: str
-	issued: int
-	expires: int
+	issued: datetime
+	expires: datetime
 
 
 @unique
@@ -59,3 +64,25 @@ class TokenMetadata(BaseModel) :
 	expires: datetime
 	issued: datetime
 	fingerprint: bytes
+
+
+@unique
+class AuthAlgorithm(Enum) :
+	ed25519: str = 'ed25519'
+
+
+class TokenResponse(BaseModel) :
+	version: str
+	algorithm: AuthAlgorithm
+	key_id: int
+	issued: datetime
+	expires: datetime
+	token: str
+
+
+class LoginResponse(BaseModel) :
+	user_id: int
+	handle: str
+	name: Optional[str]
+	mod: bool
+	token: TokenResponse
